<?php
    // Fichier de sauvegarde pour les events de l'association
    define('EVENT_FILE', 'data/event.json');
    
    function validateDate($date, $format = 'Y-m-d H:i:s'){
        $d = @DateTime::createFromFormat($format, $date);
        return $d && $d->format($format) == $date;
    }
    
    // Si le fichier est inexistant, on l'initialise avec un objet vide.
    if (!file_exists(EVENT_FILE)) {        
        file_put_contents(EVENT_FILE, json_encode(array()));        
    }
    
    // Vérification des données à sauvegarder (un "event")
    $eventDate = isset($_POST['date']) ? $_POST['date'] : '';
    $eventTitle = isset($_POST['title']) ? $_POST['title'] : '';
    $eventPlace = isset($_POST['place']) ? $_POST['place'] : '';
    // Ne prend que les lettres, espaces, apostrophes et tiret du titre
    $eventTitle = preg_replace('/[^\p{L}\p{N}\s-\']/u', '', $eventTitle);
    $eventPlace = preg_replace('/[^\p{L}\p{N}\s-\']/u', '', $eventPlace);
    
    $jsendResponse = new stdClass();  
    // Les données sont ok ?
    if (!isset($_POST['title'])) {
        $jsendResponse->status = 'fail';
        $jsendResponse->data->event = 'A title is required';
    } elseif (!isset($_POST['date'])) {
        $jsendResponse->status = 'fail';
        $jsendResponse->data->event = 'A date is required';
    } elseif (!isset($_POST['place'])) {
        $jsendResponse->status = 'fail';
        $jsendResponse->data->event = 'A place is required';
    } elseif (strlen($eventTitle) < 1 || strlen($eventTitle) > 100) {        
        $jsendResponse->status = 'error';
        $jsendResponse->data->event = 'The title is malformatted';
    } elseif (strlen($eventPlace) < 1 || strlen($eventPlace) > 100) {        
        $jsendResponse->status = 'error';
        $jsendResponse->data->event = 'The place is malformatted';
    } elseif (strlen($eventDate) != 10 || !ctype_digit(str_replace('-', '', $eventDate)) || !validateDate($eventDate, 'Y-m-d')) {
        $jsendResponse->status = 'error';
        $jsendResponse->data->event = 'The date is malformatted';
    } else {        
        $evt = new stdClass();        
        $evt->title = $eventTitle;
        $evt->date = $eventDate;        
        $evt->place = $eventPlace;
        // Rajoute l'event au events actuels
        $allEvents = json_decode(file_get_contents(EVENT_FILE));
        $allEvents[] = $evt;
        file_put_contents(EVENT_FILE, json_encode($allEvents));
        // JSEND success
        $jsendResponse->status = 'success';
        $jsendResponse->data = null;
    }           
    header('Content-type: application/json');
    die(json_encode($jsendResponse));
